### Name: geom_path
### Title: geom_path
### Aliases: geom_path GeomPath
### Keywords: hplot

### ** Examples
## Not run: 
##D # Generate data
##D myear <- ddply(movies, .(year), colwise(mean, .(length, rating)))
##D p <- ggplot(myear, aes(length, rating))
##D p + geom_path()
##D 
##D # Add aesthetic mappings
##D p + geom_path(aes(size = year))
##D p + geom_path(aes(colour = year))
##D 
##D # Change scale
##D p + geom_path(aes(size = year)) + scale_size(to = c(1, 3))
##D 
##D # Set aesthetics to fixed value
##D p + geom_path(colour = "green")
##D 
##D # Control line join parameters
##D df <- data.frame(x = 1:3, y = c(4, 1, 9))
##D base <- ggplot(df, aes(x, y))
##D base + geom_path(size = 10)
##D base + geom_path(size = 10, lineend = "round")
##D base + geom_path(size = 10, linejoin = "mitre", lineend = "butt")
##D 
##D # Use qplot instead
##D qplot(length, rating, data=myear, geom="path")
##D 
##D # Using economic data:
##D # How is unemployment and personal savings rate related?
##D qplot(unemploy/pop, psavert, data=economics)
##D qplot(unemploy/pop, psavert, data=economics, geom="path")
##D qplot(unemploy/pop, psavert, data=economics, geom="path", size=as.numeric(date))
##D 
##D # How is rate of unemployment and length of unemployment?
##D qplot(unemploy/pop, uempmed, data=economics)
##D qplot(unemploy/pop, uempmed, data=economics, geom="path")
##D qplot(unemploy/pop, uempmed, data=economics, geom="path") +
##D   geom_point(data=head(economics, 1), colour="red") + 
##D   geom_point(data=tail(economics, 1), colour="blue")
##D qplot(unemploy/pop, uempmed, data=economics, geom="path") +
##D   geom_text(data=head(economics, 1), label="1967", colour="blue") + 
##D   geom_text(data=tail(economics, 1), label="2007", colour="blue")
##D 
##D # geom_path removes missing values on the ends of a line.
##D # use na.rm = T to suppress the warning message
##D df <- data.frame(
##D   x = 1:5,
##D   y1 = c(1, 2, 3, 4, NA),
##D   y2 = c(NA, 2, 3, 4, 5),
##D   y3 = c(1, 2, NA, 4, 5),
##D   y4 = c(1, 2, 3, 4, 5))
##D qplot(x, y1, data = df, geom = c("point","line"))
##D qplot(x, y2, data = df, geom = c("point","line"))
##D qplot(x, y3, data = df, geom = c("point","line"))
##D qplot(x, y4, data = df, geom = c("point","line"))
##D 
##D # Setting line type vs colour/size
##D # Line type needs to be applied to a line as a whole, so it can
##D # not be used with colour or size that vary across a line
##D 
##D x <- seq(0.01, .99, length=100)
##D df <- data.frame(x = rep(x, 2), y = c(qlogis(x), 2 * qlogis(x)), group = rep(c("a","b"), each=100))
##D p <- ggplot(df, aes(x=x, y=y, group=group))
##D 
##D # Should work
##D p + geom_line(linetype = 2)
##D p + geom_line(aes(colour = group), linetype = 2)
##D p + geom_line(aes(colour = x))
##D 
##D # Should fail
##D p + geom_line(aes(colour = x), linetype=2)
##D 
## End(Not run)


